@@ -209,9 +209,6 @@ sub process {
         path($processable->basedir)->mkpath
           unless -e $processable->basedir;
 
-        symlink($processable->path, $processable->link)
-          unless -l $processable->link;
-
         if ($processable->can('unpack')) {
 
             my $unpack_start = [gettimeofday];
@@ -264,7 +261,7 @@ sub process {
                 unless ($current eq $tagname) {
 
                     $processable->tag('renamed-tag',
-                        "$tagname => $current at line "
+                        "$tagname => $current in line "
                           .$declared_overrides->{$tagname}{$_}{line})
                       for keys %{$declared_overrides->{$tagname}};
 
@@ -277,6 +274,19 @@ sub process {
                 }
             }
 
+            # complain about and filter out unknown tags in overrides
+            my @unknown_overrides = grep { !$self->profile->get_taginfo($_) }
+              keys %{$declared_overrides};
+            for my $tagname (@unknown_overrides) {
+
+                $processable->tag('malformed-override',
+                    "Unknown tag $tagname in line "
+                      . $declared_overrides->{$tagname}{$_}{line})
+                  for keys %{$declared_overrides->{$tagname}};
+
+                delete $declared_overrides->{$tagname};
+            }
+
             # treat ignored overrides here
             for my $tagname (keys %{$declared_overrides}) {
 
