@@ -46,13 +46,10 @@ BEGIN {
     @EXPORT_OK = (qw(
           get_file_checksum
           get_file_digest
-          do_fork
-          run_cmd
-          copy_dir
           human_bytes
           open_gz
           perm2oct
-          check_path
+          locate_executable
           normalize_pkg_path
           normalize_link_target
           is_ancestor_of
@@ -60,6 +57,7 @@ BEGIN {
           drain_pipe
           drop_relative_prefix
           read_md5sums
+          version_from_changelog
           $PKGNAME_REGEX
           $PKGREPACK_REGEX
           $PKGVERSION_REGEX
@@ -70,15 +68,12 @@ use Carp qw(croak);
 use Cwd qw(abs_path);
 use Digest::MD5;
 use Digest::SHA;
-use Encode ();
-use Errno qw(ENOENT);
-use FileHandle;
+use List::MoreUtils qw(first_value);
 use Path::Tiny;
-use POSIX qw(sigprocmask SIG_BLOCK SIG_UNBLOCK SIG_SETMASK);
-use Scalar::Util qw(openhandle);
 use Unicode::UTF8 qw(valid_utf8);
 
 use Lintian::Deb822::File;
+use Lintian::Inspect::Changelog;
 use Lintian::Relation::Version qw(versions_equal versions_comparator);
 
 use constant EMPTY => q{};
@@ -226,45 +221,6 @@ sub get_file_checksum {
     return $digest->hexdigest;
 }
 
-=item do_fork()
-
-Overrides fork to reset signal handlers etc. in the child.
-
-=cut
-
-sub do_fork() {
-    my ($pid, $fork_error);
-    my $orig_mask = POSIX::SigSet->new;
-    my $fork_mask = POSIX::SigSet->new;
-    $fork_mask->fillset;
-    sigprocmask(SIG_BLOCK, $fork_mask, $orig_mask)
-      or die("sigprocmask failed: $!\n");
-    $pid = CORE::fork();
-    $fork_error = $!;
-    if (defined($pid) and $pid == 0) {
-
-        for my $sig (keys(%SIG)) {
-            if (ref($SIG{$sig}) eq 'CODE') {
-                $SIG{$sig} = 'DEFAULT';
-            }
-        }
-    }
-    if (!sigprocmask(SIG_SETMASK, $orig_mask, undef)) {
-        # The child MUST NOT use die as the caller cannot distinguish
-        # the caller from the child via an exception.
-        my $sigproc_error = $!;
-        if (not defined($pid) or $pid != 0) {
-            die("sigprocmask failed (do_fork, parent): $sigproc_error\n");
-        }
-        print STDERR "sigprocmask failed (do_fork, child): $sigproc_error\n";
-        POSIX::_exit(255);
-    }
-    if (not defined($pid)) {
-        $! = $fork_error;
-    }
-    return $pid;
-}
-
 =item perm2oct(PERM)
 
 Translates PERM to an octal permission.  PERM should be a string describing
@@ -329,108 +285,6 @@ sub perm2oct {
     return $octal;
 }
 
-=item run_cmd([OPTS, ]COMMAND[, ARGS...])
-
-Executes the given C<COMMAND> with the (optional) arguments C<ARGS> and
-returns the status code as one would see it from a shell script.  Shell
-features cannot be used.
-
-OPTS, if given, is a hash reference with zero or more of the following key-value pairs:
-
-=over 4
-
-=item chdir
-
-The child process with chdir to the given directory before executing the command.
-
-=item in
-
-The STDIN of the child process will be reopened and read from the filename denoted by the value of this key.
-By default, STDIN will reopened to read from /dev/null.
-
-=item out
-
-The STDOUT of the child process will be reopened and write to filename denoted by the value of this key.
-By default, STDOUT is discarded.
-
-=item update-env-vars
-
-Each key/value pair defined in the hashref associated with B<update-env-vars> will be updated in the
-child processes's environment.  If a value is C<undef>, then the corresponding environment variable
-will be removed (if set).  Otherwise, the environment value will be set to that value.
-
-=back
-
-=cut
-
-sub run_cmd {
-    my (@cmd_args) = @_;
-    my ($opts, $pid);
-    if (ref($cmd_args[0]) eq 'HASH') {
-        $opts = shift(@cmd_args);
-    } else {
-        $opts = {};
-    }
-    $pid = do_fork();
-    if (not defined($pid)) {
-        # failed
-        die("fork failed: $!\n");
-    } elsif ($pid > 0) {
-        # parent
-        waitpid($pid, 0);
-        if ($?) {
-            my $exit_code = ($? >> 8) & 0xff;
-            my $signal = $? & 0x7f;
-            my $cmd = join(' ', @cmd_args);
-            if ($exit_code) {
-                die("Command $cmd returned: $exit_code\n");
-            } else {
-                my $signame = signal_number2name($signal);
-                die("Command $cmd received signal: $signame ($signal)\n");
-            }
-        }
-    } else {
-        # child
-        if (defined(my $env = $opts->{'update-env-vars'})) {
-            while (my ($k, $v) = each(%{$env})) {
-                if (defined($v)) {
-                    $ENV{$k} = $v;
-                } else {
-                    delete($ENV{$k});
-                }
-            }
-        }
-        if ($opts->{'in'}) {
-            open(STDIN, '<', $opts->{'in'});
-        } else {
-            open(STDIN, '<', '/dev/null');
-        }
-        if ($opts->{'out'}) {
-            open(STDOUT, '>', $opts->{'out'});
-        } else {
-            open(STDOUT, '>', '/dev/null');
-        }
-        chdir($opts->{'chdir'}) if $opts->{'chdir'};
-        # Avoid shell evaluation.
-        CORE::exec {$cmd_args[0]} @cmd_args
-          or die("Failed to exec '$_[0]': $!\n");
-    }
-    return 1;
-}
-
-=item copy_dir (ARGS)
-
-Convenient way of calling I<cp -a ARGS>.
-
-=cut
-
-sub copy_dir {
-    # --reflink=auto (coreutils >= 7.5).  On FS that support it,
-    # make a CoW copy of the data; otherwise fallback to a regular
-    # deep copy.
-    return run_cmd('cp', '-a', '--reflink=auto', '--', @_);
-}
-
 =item human_bytes(SIZE)
 
 =cut
@@ -521,22 +375,20 @@ If the tool cannot be found, this sub will cause a trappable error.
     }
 }
 
-=item check_path (CMD)
-
-Returns 1 if CMD can be found in PATH (i.e. $ENV{PATH}) and is
-executable.  Otherwise, the function return 0.
+=item locate_executable (CMD)
 
 =cut
 
-sub check_path {
-    my $command = shift;
+sub locate_executable {
+    my ($command) = @_;
 
-    return 0 unless exists $ENV{PATH};
-    for my $element (split ':', $ENV{PATH}) {
-        next unless length $element;
-        return 1 if -f "$element/$command" and -x _;
-    }
-    return 0;
+    return EMPTY
+      unless exists $ENV{PATH};
+
+    my @folders =  grep { length } split(/:/, $ENV{PATH});
+    my $path = first_value { -x "$_/$command" } @folders;
+
+    return ($path // EMPTY);
 }
 
 =item drop_relative_prefix(STRING)
@@ -554,36 +406,28 @@ sub drop_relative_prefix {
     return $copy;
 }
 
-=item signal_number2name(NUM)
-
-Given a number, returns the name of the signal (without leading
-"SIG").  Example:
-
-    signal_number2name(2) eq 'INT'
+=item version_from_changelog
 
 =cut
 
-{
-    my @signame;
+sub version_from_changelog {
+    my ($package_path) = @_;
 
-    sub signal_number2name {
-        my ($number) = @_;
-        if (not @signame) {
-            require Config;
-            # Doubt this happens for Lintian, but the code might
-            # Cargo-cult-copied or copy-wasted into another project.
-            # Speaking of which, thanks to
-            #  http://www.ccsf.edu/Pub/Perl/perlipc/Signals.html
-            defined($Config::Config{sig_name})
-              or die "Signals not available\n";
-            my $i = 0;
-            for my $name (split(' ', $Config::Config{sig_name})) {
-                $signame[$i] = $name;
-                $i++;
-            }
-        }
-        return $signame[$number];
-    }
+    my $changelog_path = "$package_path/debian/changelog";
+
+    return EMPTY
+      unless -f $changelog_path;
+
+    my $contents = path($changelog_path)->slurp_utf8;
+    my $changelog = Lintian::Inspect::Changelog->new;
+
+    $changelog->parse($contents);
+    my @entries = @{$changelog->entries};
+
+    return $entries[0]->{'Version'}
+      if @entries;
+
+    return EMPTY;
 }
 
 =item normalize_pkg_path(PATH)
